<?php
/**
 * Reef functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 * @since Reef 0.1
 */

/**
 * Reef only works in WordPress 4.7 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
	return;
}

function reef_scripts(){
	wp_enqueue_style( 'reef-google-fonts', esc_url( '//fonts.googleapis.com/css?family=Lato:300,400,400i,700,900|Niconne' ) );

	# Styles
	# use get_theme_file_uri(). So that child theme can overwrite it.
	# @link  https://developer.wordpress.org/reference/functions/get_theme_file_uri/
	wp_enqueue_style( 'sidr', get_theme_file_uri( '/assets/vendors/sidr/css/jquery.sidr.dark.min.css' ), array(), '2.2.1' );
	wp_enqueue_style( 'fontawesome', get_theme_file_uri( '/assets/vendors/font-awesome/css/font-awesome.min.css' ), array(), '4.7.0' );
	wp_enqueue_style( 'bootstrap', get_theme_file_uri( '/assets/vendors/bootstrap/css/bootstrap.min.css' ), array(), '3.3.7' );
	wp_enqueue_style( 'colorbox', get_theme_file_uri( '/assets/vendors/colorbox/css/colorbox.min.css' ) );
	wp_enqueue_style( 'reef-blocks', get_theme_file_uri( '/assets/css/blocks.min.css' ) );

	wp_enqueue_style( 'reef-style', get_stylesheet_uri(), array(), '0.1' );
	# Scripts
	wp_enqueue_script( 'jquery-sidr', get_theme_file_uri( '/assets/vendors/sidr/js/jquery.sidr.min.js' ), array( 'jquery' ), '2.2.1', true );
	wp_enqueue_script( 'jquery-cycle2', get_theme_file_uri( '/assets/vendors/cycle2/js/jquery.cycle2.min.js' ), array( 'jquery' ), '2.1.6', true );
	wp_enqueue_script( 'jquery-bootstrap', get_theme_file_uri( '/assets/vendors/bootstrap/js/bootstrap.min.js' ), array( 'jquery' ), '2.1.6', true );

	if( reef_get_option( 'enable_sticky_sidebar' ) ){
		wp_enqueue_script( 'jquery-sticky-sidebar', get_theme_file_uri( '/assets/vendors/sticky-sidebar/sticky-sidebar.min.js' ), array( 'jquery' ), null, true );
	}

	wp_enqueue_script( 'jquery-colorbox', get_theme_file_uri( '/assets/vendors/colorbox/js/jquery.colorbox-min.js' ), array( 'jquery' ), '2.9.0', true );
	
	# Enqueue the main script of this theme.
	# This is the archived js from assets/js/partials directory.
	wp_enqueue_script( 'reef-main', get_theme_file_uri( '/assets/js/main.min.js' ), array( 'jquery', 'masonry' ), '1.0', true );
	wp_enqueue_script( 'reef-main', get_theme_file_uri( '/assets/js/skip-link-focus-fix.min.js' ), array( 'jquery', 'reef-skip-link-focus-fix' ), '1.0', true );
	wp_localize_script( 'reef-main', 'REEF', array(
		'is_admin_bar_showing'        => is_admin_bar_showing() ? true : false,
		'enable_scroll_top_in_mobile' => reef_get_option( 'enable_scroll_top_in_mobile' ) ? 1 : 0,
		'enable_sticky_sidebar'       => reef_get_option( 'enable_sticky_sidebar' )
	) );

	if ( is_singular() && comments_open() ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'reef_scripts' );

/**
* Enqueue editor styles for Gutenberg
*/
function reef_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'reef-block-editor-style', get_theme_file_uri( '/assets/css/editor-blocks.min.css' ) );
	// Google Font
	wp_enqueue_style( 'reef-google-font', 'https://fonts.googleapis.com/css?family=Poppins:300,400,400i,500,600,700,700i', false );
}
add_action( 'enqueue_block_editor_assets', 'reef_block_editor_styles' );


/**
* Print Inline styles
*
* @since Reef 1.3
* @return void
*/
function reef_inline_styles(){
	?>

	<style type="text/css">
		.nav-links .nav-next a:before{
			content : "<?php esc_html_e( 'Next Reading', 'reef' ); ?>";
		}

		.nav-links .nav-previous a:before{
			content : "<?php esc_html_e( 'Previous Reading', 'reef' ); ?>";
		}
	</style>
	<?php
}
add_action( 'wp_head', 'reef_inline_styles' );

/**
* Disable the excerpt "Read More" text
*
* @since Reef 0.1
* @param string $more
* @return string 
*/
function reef_excerpt_more( $more ) {
	return '';
}
add_filter( 'excerpt_more', 'reef_excerpt_more' );

/**
 * Use front-page.php when Front page displays is set to a static page.
 *
 * @since Reef 0.1
 * @param string $template front-page.php.
 * @return string The template to be used: blank if is_home() is true (defaults to index.php), else $template.
 */
function reef_front_page_template( $template ) {

	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'reef_front_page_template' );

/**
* Adds a submit button in search form
* 
* @since Reef 0.1
* @param string $form
* @return string
*/
function reef_modify_search_form( $form ){
	return str_replace( '</form>', '<button type="submit" class="search-button"><i class="fa fa-search"></i></button></form>', $form );
}
add_filter( 'get_search_form', 'reef_modify_search_form' );

/**
* Modify some markup for comment section
*
* @since Reef 0.1
* @param array $defaults
* @return array $defaults
*/
function reef_modify_comment_form_defaults( $defaults ){

	$user = wp_get_current_user();
	$user_identity = $user->exists() ? $user->display_name : '';

	$defaults[ 'logged_in_as' ] = '<p class="logged-in-as">' . sprintf(
		                              /* translators: 1: edit user link, 2: accessibility text, 3: user name, 4: logout URL */
		                              __( '<a href="%1$s" aria-label="%2$s">Logged in as %3$s</a> <a href="%4$s">Log out?</a>', 'reef' ),
		                              get_edit_user_link(),
		                              /* translators: %s: user name */
		                              esc_attr( sprintf( __( 'Logged in as %s. Edit your profile.', 'reef' ), $user_identity ) ),
		                              $user_identity,
		                              wp_logout_url( apply_filters( 'the_permalink', get_permalink( get_the_ID() ) ) )
		                          ) . '</p>';
	return $defaults;
}
add_filter( 'comment_form_defaults', 'reef_modify_comment_form_defaults',99 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 *
 * @since Reef 0.1
 * @return void
 */
function reef_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", get_bloginfo( 'pingback_url' ) );
	}
}
add_action( 'wp_head', 'reef_pingback_header' );

/**
* Restrict highlighted posts and posts in slider in main query
*
* @since Reef 0.1
* @param object $query
* @uses reef_get_slider_args()
* @return void
*/
function reef_post_queries( $query ) {
	# Do not alter the query on wp-admin pages and only alter it if it's the main query
	if ( !is_admin() && $query->is_main_query() ){

		# is_front_page throws a notice while reading setting is static page
		# so reef_is_root() is used
		# $_GET[ 'infinity' ] is checked to by pass this on jetpack's load more 

		if( reef_is_root() && ! isset( $_GET[ 'infinity' ] ) ){
			
			# Don't show the posts which are in highligted post sections. 
			$post_ids = array();
			if( ! reef_get_option( 'disable_highlighted_posts' ) ){
				for( $i = 1; $i <= 3; $i++ ){
					$post_id = absint( reef_get_option( 'highlighted_post_' . $i ) );
					if( $post_id ){
						array_push( $post_ids, $post_id );
					}
				}
			}

			# Don't show the posts which are in slider.
			$slider_args = apply_filters( 'reef_slider_query_args', reef_get_slider_args() );

			if( $slider_args ){
				$the_query = new WP_Query( $slider_args );
				while ( $the_query->have_posts() ) :  $the_query->the_post();
					array_push( $post_ids, get_the_ID() );
				endwhile;
				wp_reset_postdata();
			}

			$query->set( 'post__not_in', $post_ids );
		}
	}
}
add_action( 'pre_get_posts', 'reef_post_queries',11 );

/**
* Remove 'has-post-thumbnail' class in post block when post format is gallery and contains featured image
*
* @since Reef 0.1
* @param array $class
* @return array $class
*/
function reef_post_class_modification( $class ){

	$video = false;
	
	if( 'video' == get_post_format() ){
		$content = apply_filters( 'the_content', get_the_content() );
		$video   = get_media_embedded_in_content( $content, array( 'video', 'object', 'embed', 'iframe' ) );
	}

	if( ( is_home() || is_archive() ) && has_post_thumbnail() && ( ( 'gallery' == get_post_format() && get_post_gallery() ) || ( 'video' == get_post_format() && !empty( $video ) ) ) ){

		foreach ( $class as $key => $value ){
		    if ( 'has-post-thumbnail' == $value ) {
		        unset( $class[ $key ] );
		    }
		}
	}

	return $class;
}
add_filter( 'post_class', 'reef_post_class_modification' );

/**
* Add a class in body when previewing customizer
*
* @since Reef 0.1
* @param array $class
* @return array $class
*/
function reef_body_class_modification( $class ){
	if( is_customize_preview() ){
		$class[] = 'keon-customizer-preview';
	}

	return $class;
}
add_filter( 'body_class', 'reef_body_class_modification' );

/**
* query arguments for homepage slider or banner
*
* @since Reef 0.1
* @return bool | array
*/
if( ! function_exists( 'reef_get_slider_args' ) ):
function reef_get_slider_args(){

	$slide_opt = reef_get_option( 'slider_post_option' );

	if( 'slider' == $slide_opt ){

		$slider_cat = absint( reef_get_option( 'slider_category' ) );
		if( $slider_cat ){
			
			return array(
				'posts_per_page' => 3,
				'post_status'    => 'publish',
				'order'          => 'DESC',
				'orderby'        => 'date',
				'category__in'   => $slider_cat,
			); 
		}
	}elseif( 'banner' == $slide_opt ){

		$post_id = absint( reef_get_option( 'banner_post' ) );
		if( $post_id ){
			return array(
				'p'           => $post_id,
				'post_status' => 'publish',
			);
		}
	}
	
	return false;
}
endif;

require_once get_parent_theme_file_path( '/inc/setup.php' );
require_once get_parent_theme_file_path( '/inc/template-tags.php' );
require_once get_parent_theme_file_path( '/inc/hooks/init.php' );
require_once get_parent_theme_file_path( '/modules/loader.php' );
require_once get_parent_theme_file_path( '/theme-info/theme-info.php' );