<?php
/**
 * The header for our theme
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 * @since Reef 0.1
 */
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>
<?php
$primary_menu = wp_nav_menu( apply_filters( 'reef_primary_menu', array(
    'theme_location' => 'primary',
    'menu_id'        => 'primary-menu',
    'menu_class'     => 'primary-menu',
    'fallback_cb'    => 'reef_primary_menu_fb',
    'echo'			 => false,
    'container'      => false	
) ) );

$social_menu = wp_nav_menu( apply_filters( 'reef_social_menu', array(
    'theme_location' => 'social',
    'depth'          => 1,
    'fallback_cb'    => false,
    'echo'           => false,
    'container'      => false
) ) );

$alternative_menu = wp_nav_menu( apply_filters( 'reef_alternative_menu', array(
	'theme_location' => 'alternative_menu',
	'fallback_cb'    => false,
	'echo'           => false,
	'container'      => false
) ) );
?>
<body <?php body_class(); ?>>
<?php do_action( 'wp_body_open' ); ?>
	
	<div class="search-section">
		<div class="container">
			<div id="search-form">
				<?php get_search_form(); ?>
				<span class="search-close">
					<i class="fa fa-close"></i>
				</span>
			</div><!-- /#search-form -->
		</div>
	</div>
	<section class="box-layout">
		<!-- alternate menu -->
	    <div id="alternate-menu" class="hidden">
	    	<span class="bars sidr-close">
				<a class="inner-bars">
					<span class="bar"></span>
					<span class="bar"></span>
					<span class="bar"></span>
					<span class="bar"></span>
				</a>
			</span>
	    	<div id="primary-nav-alt" class="alt-menu-box">
	    		<h3 class="menu-title hidden-md hidden-lg"><?php echo esc_html__( 'Primary Menu', 'reef' );?></h3>
	    		<?php echo $primary_menu; ?>
	    	</div>
	    	
	    	<?php if( $alternative_menu ): ?>
	    	<div id="alt-menu" class="alt-menu-box secondary-menu" style="display: <?php echo esc_attr( reef_get_option( 'enable_alt_menu' ) ? 'block': 'none' ); ?>">
	    		<h3 class="menu-title hidden-md hidden-lg"><?php echo esc_html__( 'Secondary Menu', 'reef' );?></h3>
				<?php echo $alternative_menu; ?>
			</div>
			<?php endif; ?>
			
			<?php if( $social_menu ): ?>
			<div id="social-nav-alt" class="alt-menu-box socialgroup">
	    		<h3 class="menu-title hidden-md hidden-lg"><?php echo esc_html__( 'Social Menu', 'reef' );?></h3>
				<?php echo $social_menu; ?>
			</div>
			<?php endif; ?>
	    </div>

		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content">
				<?php echo esc_html__( 'Skip to content', 'reef' ); ?>
			</a>
			
			<header id="masthead" class="wrapper site-header" role="banner">
				<div class="container">
					<?php get_template_part( 'template-parts/header/site', 'branding' ); ?>
				</div>
				<div class="clearfix"></div>
				<div class="container">
					<div class="row">
						<div class="col-xs-12 col-sm-12 col-md-9">
							<div class="wrap-nav main-navigation">
								<div id="navigation" class="hidden-xs hidden-sm">
								    <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'reef' ); ?>">
										<?php echo $primary_menu; ?>
								    </nav>
								</div>
							</div>
						</div>
						<div class="col-xs-12 col-sm-12 col-md-3">
							<div class="header-bottom-right">
								<nav class="socialgroup hidden-xs hidden-sm">
									<?php echo $social_menu; ?>
								</nav>
								<?php if( !reef_get_option( 'disable_search_icon' ) ): ?>
									<span class="search-icon">
										<a href="#">
											<i class="fa fa-search" aria-hidden="true"></i>
										</a>
									</span>
								<?php endif; ?>
								<span class="alt-menu-icon" style="display: <?php echo esc_attr( ! reef_get_option( 'enable_alt_menu' ) ? 'none': 'inline-block' ); ?>">
									<a class="alternate-menu-toggler" href="#">
										<span class="bars">
											<span class="bar"></span>
											<span class="bar"></span>
											<span class="bar"></span>
											<span class="bar"></span>
										</span>
									</a>
								</span>
							</div>
						</div>	
					</div>
				</div>
			</header><!-- #masthead -->
			<section class="wrapper wrap-site-content">
				<div id="content" class="site-content">